@@ -8,6 +8,7 @@ use HTTP::Headers;
 use HTTP::Request;
 use Scalar::Util qw(blessed);
 use MooseX::Semantic::Types qw( TrineLiteral);
+use Log::Log4perl;
 use Data::Dumper;
 
 with (
@@ -15,6 +16,8 @@ with (
     'MooseX::Semantic::Util::TypeConstraintWalker',
 );
 
+my $logger = Log::Log4perl->get_logger('moosex.semantic.rdfexport');
+
 =head1 NAME
 
 MooseX::Semantic::Role::RdfExport - Role for exporting Moose objects to RDF
@@ -176,7 +179,7 @@ sub _export_one_object {
                 $context,
             );
         } else {
-            warn "Can't export this object since it doesn't MooseX::Semantic::Role::RdfExport";
+            $logger->error( "Can't export this object since it doesn't MooseX::Semantic::Role::RdfExport: " . Dumper($single_val));
         }
     }
     else {
